@@ -2,8 +2,8 @@ import json
 import re
 
 class ApiErrors(Exception):
-    def __init__(self):
-        self.errors = {}
+    def __init__(self, errors: dict = None):
+        self.errors = errors if errors else {}
 
     def add_error(self, field, error):
         if field in self.errors:
@@ -17,6 +17,10 @@ class ApiErrors(Exception):
         else:
             self.add_error(field, 'format is invalid')
 
+    def check_email(self, field, value):
+        if not "@" in value:
+            self.add_error(field, 'L\'e-mail doit contenir un @.')
+
     def check_float(self, field, value):
         if isinstance(value, float) or \
            (isinstance(value, (str, unicode)) and re.search('^\d+(\.\d*|)$', value)):
@@ -24,6 +28,10 @@ class ApiErrors(Exception):
         else:
             self.add_error(field, 'value must be a number.')
 
+    def check_min_length(self, field, value, length):
+        if len(value) < length:
+            self.add_error(field, 'value should be long at least of ' + str(length) + ' characters.')
+
     def maybe_raise(self):
         if len(self.errors) > 0:
             raise self
@@ -40,6 +48,9 @@ class DateTimeCastError(ApiErrors):
 class DecimalCastError(ApiErrors):
     pass
 
+class EmptyFiltersError(ApiErrors):
+    pass
+
 class ForbiddenError(ApiErrors):
     pass
 
